Name:           python-%{gitname}
Version:        0.9.18
%global         rel             3

License:        ASL 1.1 and zlib
URL:            https://github.com/CoreSecurity/impacket



#global         gituser         CoreSecurity
%global         gituser         SecureAuthCorp
%global         gitname         impacket
%global         commit          462449c1bc774d725b38f31d4fa32ec7dfaac22e
%global         gitdate         20181205
%global         shortcommit     %(c=%{commit}; echo ${c:0:7})

%global         sum             Collection of Python classes providing access to network packets

#Have the python3 stuff ready, but do not build for python3 now as the project is not ready
%global         with_python3    0
%global         with_tests      0

#Python sitearch/sitelib macros for RHEL6
%if 0%{?rhel} && 0%{?rhel} <= 6
%{!?__python2:        %global __python2 /usr/bin/python2}
%{!?python2_sitelib:  %global python2_sitelib %(%{__python2} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python2_sitearch: %global python2_sitearch %(%{__python2} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
%endif

#Python build/install macros for older platforms
%if 0%{?fedora} <= 21
 %{!?py2_build:         %global py2_build       %{__python2} setup.py build --executable="%{__python2} -s"}
 %{!?py2_install:       %global py2_install     %{__python2} setup.py install -O1 --skip-build --root %{buildroot}}
 %{!?py3_build:         %global py3_build       %{__python3} setup.py build --executable="%{__python3} -s"}
 %{!?py3_install:       %global py3_install     %{__python3} setup.py install -O1 --skip-build --root %{buildroot}}
%endif

%global         pkgver          %(echo %{version} | sed 's/\\./_/g')

# Build source is github release=1 or git commit=0
%global         build_release    1

%if 0%{?build_release}  > 0
Release:        %{rel}%{?dist}
Source0:        https://github.com/CoreSecurity/impacket/releases/download/%{gitname}_%{pkgver}/%{gitname}-%{version}.tar.gz
%else:
Release:        %{rel}.%{gitdate}git%{shortcommit}%{?dist}
Source0:        https://github.com/%{gituser}/%{gitname}/archive/%{commit}/%{name}-%{version}-%{shortcommit}.tar.gz
%endif #Build_release

Summary:        %{sum}


# This patch removes the check for presence of the argparse python package for the 
# python version < 2.7. The way how it is checked required setuptools newer than
# what is available in EPEL7 EL6 repositories and breaks the build
Patch0:         python-impacket-setup.patch


BuildArch:      noarch

BuildRequires:  sed
BuildRequires:  grep
BuildRequires:  python2
BuildRequires:  python2-devel
BuildRequires:  python2-setuptools

%if 0%{?with_python3}
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
%endif # with_python3



%description
Impacket is a collection of Python classes focused on providing access to
network packets. Impacket allows Python developers to craft and decode network
packets in simple and consistent manner. it is highly effective when used in
conjunction with a packet capture utility or package such as Pcapy. Packets
can be constructed from scratch, as well as parsed from raw data. Furthermore,
the object oriented API makes it simple to work with deep protocol hierarchies.



#===== the python2 package definition
%package -n python2-%{gitname}
Summary:        %{sum}
%{?python_provide:%python_provide python2-%{gitname}}
Provides:       %{name} = %{version}-%{release}
Provides:       impacket = %{version}-%{release}

Requires:       python2-ldap3

# Used by psexec.py
Requires:       python2-crypto
Requires:       python2-pyasn1

# Used by
Requires:       pcapy

# Used by impacket/examples/ntlmrelayx/servers/socksserver.py
Requires:       python2-httplib2

%if 0%{?rhel} && 0%{?rhel} == 7
Requires:       pyOpenSSL
Requires:       python-flask
%else
# Used by some of the example scripts, not correctly detected
Requires:       python2-pyOpenSSL
# Used by impacket/examples/ntlmrelayx/servers/socksserver.py
Requires:       python2-flask
%endif



%description -n python2-%{gitname}
Python2 package of %{name}.
Impacket is a collection of Python classes focused on providing access to
network packets. Impacket allows Python developers to craft and decode network
packets in simple and consistent manner. it is highly effective when used in
conjunction with a packet capture utility or package such as Pcapy. Packets
can be constructed from scratch, as well as parsed from raw data. Furthermore,
the object oriented API makes it simple to work with deep protocol hierarchies.



#===== the python3 package definition
%if 0%{?with_python3}
%package -n python3-%{gitname}
Summary:        %{sum}
%{?python_provide:%python_provide python3-%{gitname}}

%description -n python3-%{gitname}
Python3 package of %{name}.
Impacket is a collection of Python classes focused on providing access to
network packets. Impacket allows Python developers to craft and decode network
packets in simple and consistent manner. it is highly effective when used in
conjunction with a packet capture utility or package such as Pcapy. Packets
can be constructed from scratch, as well as parsed from raw data. Furthermore,
the object oriented API makes it simple to work with deep protocol hierarchies.

%endif # with_python3



#===== Preparation
%prep
%if 0%{?build_release} > 0
# Build from git release version
%autosetup -n %{gitname}-%{version}

%else
# Build from git commit
%autosetup -n %{gitname}-%{commit}
%endif #build_release

# Clean-up

#sed -i -e '1i#!/usr/bin/env python' examples/*

# Removing shabang from examples libraries, which are not executable
# Doesn't contain main __main__ or unfunctioned code
# https://github.com/CoreSecurity/impacket/issues/406
sed -i -e '/#!\/usr\/bin\/env python/d' \
    impacket/ese.py \
    impacket/tds.py \
    impacket/examples/logger.py \
    impacket/examples/ntlmrelayx/clients/*.py \
    impacket/examples/ntlmrelayx/servers/socksplugins/*.py \
    impacket/examples/ntlmrelayx/servers/__init__.py \
    impacket/examples/ntlmrelayx/servers/httprelayserver.py \
    impacket/examples/ntlmrelayx/servers/smbrelayserver.py \
    impacket/examples/ntlmrelayx/utils/*.py

# Use explicit python2 shabeng instead of generic env python
# to get prepared for switch the default to python3
sed -i -e 's|#!/usr/bin/env python|#!/usr/bin/python2|' \
    impacket/mqtt.py \
    impacket/examples/ntlmrelayx/servers/socksserver.py

# Moving uncrc32
# https://github.com/CoreSecurity/impacket/issues/403
sed -i -e 's|^import uncrc32|from impacket.examples import uncrc32|;' examples/nmapAnswerMachine.py



#===== Build
%build
%py2_build

%if 0%{?with_python3}
%py3_build
%endif # with_python3



#===== Install
%install
%py2_install
#now in license directory
rm -f %{buildroot}%{_defaultdocdir}/%{name}/LICENSE

%if 0%{?with_python3}
%py3_install
%endif # with_python3




#===== files for python2 package
%files -n       python2-%{gitname}
%license        LICENSE
%doc            ChangeLog README.md
%{python2_sitelib}/%{gitname}/
%{python2_sitelib}/%{gitname}*.egg-info
%exclude %{_defaultdocdir}/%{gitname}
%exclude %{_defaultdocdir}/%{gitname}/testcases/*
%exclude %{_defaultdocdir}/%{gitname}/README.md
%{_bindir}/*.py



#===== files for python3 package
%if 0%{?with_python3}

%files -n       python3-%{gitname}
%license        LICENSE
%doc            ChangeLog README.md
%{python3_sitelib}/%{gitname}*.egg-info
%{python3_sitelib}/__pycache__/*
%exclude %{_defaultdocdir}/%{gitname}
%exclude %{_defaultdocdir}/%{gitname}/testcases/*
%exclude %{_defaultdocdir}/%{gitname}/README.md
%{_bindir}/*.py

%endif # with_python3


%changelog
* Tue Feb 05 2019 Michal Ambroz <rebus _AT seznam.cz> - 0.9.18-3
- conditional dependencies for EPEL7 - python-flask and pyOpenSSL

* Mon Feb 04 2019 Michal Ambroz <rebus _AT seznam.cz> - 0.9.18-2
- add missing dependencies for EPEL7 - python2-setuptools
- patch setup.py to remove python_version to meet RHEL7 setuptools version

* Mon Feb 04 2019 Michal Ambroz <rebus _AT seznam.cz> - 0.9.18-1
- bump to version 0.9.18 

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.9.17-0.4.20180308gite0af5bb
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.9.17-0.3.20180308gite0af5bb
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Mar 12 2018 Michal Ambroz <rebus _AT seznam.cz> - 0.9.17-0.2
- fix python runtime dependencies #1506227

* Sun Mar 11 2018 Michal Ambroz <rebus _AT seznam.cz> - 0.9.17-0.1
- bump to development version of 0.9.17 as there won't be any 0.9.16

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.9.15-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.9.15-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.9.15-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Sep 12 2016 Michal Ambroz <rebus _AT seznam.cz> - 0.9.15-4
- fix python provides for the python-impacket

* Wed Aug 24 2016 Michal Ambroz <rebus _AT seznam.cz> - 0.9.15-3
- python2/3 split package, disable python3 subpackage by default
- fix FTBFS

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.15-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Jul 14 2016 Fabian Affolter <mail@fabian-affolter.ch> - 0.9.15-1
- Update to latest upstream release (rhb#1307918)

* Tue Mar 01 2016 Michal Ambroz <rebus _AT seznam.cz> - 0.9.14-1
- Updated to new upstream release 0.9.14
- as Impacket upstream is not ready for python3 I propose to have the py3
  building ready, but disabled by default

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.9.13-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sun Nov 15 2015 Fabian Affolter <mail@fabian-affolter.ch> - 0.9.13-2
- Cleanup and py3

* Wed Jul 22 2015 Fabian Affolter <mail@fabian-affolter.ch> - 0.9.13-1
- Updated to new upstream release 0.9.13
- Fix FTBS (rhbz#1239842)

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.12-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Mar 12 2015 Fabian Affolter <mail@fabian-affolter.ch> - 0.9.12-1
- Updated to new upstream release 0.9.12

* Sat Jun 28 2014 Fabian Affolter <mail@fabian-affolter.ch> - 0.9.11-2
- Move files out of /usr/bin
- Update licence (according to mailing list)

* Wed Feb 26 2014 Fabian Affolter <mail@fabian-affolter.ch> - 0.9.11-1
- Updated to new upstream release 0.9.11

* Sat Aug 10 2013 Fabian Affolter <mail@fabian-affolter.ch> - 0.9.10-1
- Updated to new upstream release 0.9.10

* Sat Nov 17 2012 Fabian Affolter <mail@fabian-affolter.ch> - 0.9.9.9-1
- Initial package

